@@ -1,4 +1,4 @@
-from typing import Sequence
+from typing import Sequence, Dict, Iterable, Callable
 import os
 import string
 import itertools
@@ -7,18 +7,29 @@ import pandas as pd
 from openpyxl.utils.dataframe import dataframe_to_rows
 
 from exceldriver.workbook.create import get_workbook_and_worksheet
-from .commands import financial_data_command, id_command, name_command, holdings_command
+from exceldriver.columns import excel_cols
+from .commands import financial_data_command, id_command, name_command, holdings_command, market_data_command
 
-def create_all_xlsx_with_financials_commands(folder, company_id_list, data_items_dict, **financials_kwargs):
+
+def create_all_xlsx_with_commands(folder: str, company_id_list: Sequence[str],
+                                  financial_data_items_dict: Dict[str, str],
+                                  market_data_items_dict: Dict[str, str], **financials_kwargs):
     [
-        create_xlsx_with_financials_commands(folder, company_id, data_items_dict, **financials_kwargs)
+        create_xlsx_with_commands(
+            folder,
+            company_id,
+            financial_data_items_dict,
+            market_data_items_dict,
+            **financials_kwargs
+        )
         for company_id in company_id_list
     ]
 
 
-def create_xlsx_with_financials_commands(folder, company_id, data_items_dict, **financials_kwargs):
+def create_xlsx_with_commands(folder: str, company_id: str, financial_data_items_dict: Dict[str, str],
+                              market_data_items_dict: Dict[str, str], **financials_kwargs):
     wb, ws = get_workbook_and_worksheet()
-    _fill_with_financials_commands(ws, company_id, data_items_dict, **financials_kwargs)
+    _fill_with_commands(ws, company_id, financial_data_items_dict, market_data_items_dict, **financials_kwargs)
 
     if not os.path.exists(folder):
         os.makedirs(folder)
@@ -47,6 +58,9 @@ def create_xlsx_with_holdings_commands(folder, company_id, date_str, data_items_
 def create_all_xlsx_with_id_commands(ids: Sequence[str], folder, num_files=100):
     wb, ws = get_workbook_and_worksheet()
 
+    if not os.path.exists(folder):
+        os.makedirs(folder)
+
     df = pd.DataFrame()
     _fill_id_column(df, ids)
     _fill_capiq_id_column(df)
@@ -101,7 +115,8 @@ def _fill_capiq_name_column(df):
     # Blank needed because ids will populate to the right by one column
     df['IQ Name'] = ''
 
-def _fill_with_financials_commands(ws, company_id, data_items_dict, **financials_kwargs):
+def _fill_with_commands(ws, company_id: str, financial_data_items_dict: Dict[str, str],
+                        market_data_items_dict: Dict[str, str], **financials_kwargs):
     """
     Note: inplace
     """
@@ -112,17 +127,34 @@ def _fill_with_financials_commands(ws, company_id, data_items_dict, **financials
     except KeyError:
         freq = 'Q'
 
-    date_var, date_var_label = _get_date_var_and_label_from_freq(freq)
+    date_dict = _get_date_var_dict_from_freq(freq)
 
     column_generator = excel_cols()
 
-    # Fill dates first
-    current_column = next(column_generator)
-    ws[f'{current_column}1'] = financial_data_command(company_id, date_var, **financials_kwargs, data_item_label=date_var_label)
+    common_args = (
+        column_generator,
+        ws,
+        company_id
+    )
 
+    _fill_ws_by_data_item_dict(date_dict, financial_data_command, *common_args, **financials_kwargs)
+    _fill_ws_by_data_item_dict(financial_data_items_dict, financial_data_command, *common_args, **financials_kwargs)
+    _fill_ws_by_data_item_dict(market_data_items_dict, market_data_command, *common_args, **financials_kwargs)
+
+
+
+def _fill_ws_by_data_item_dict(data_items_dict: Dict[str, str], command_func: Callable,
+                               column_generator: Iterable, ws,
+                               company_id: str, **financials_kwargs):
     for item in data_items_dict:
         current_column = next(column_generator)
-        ws[f'{current_column}1'] = financial_data_command(company_id, item, **financials_kwargs, data_item_label=data_items_dict[item])
+        ws[f'{current_column}1'] = command_func(
+            company_id,
+            item,
+            **financials_kwargs,
+            data_item_label=data_items_dict[item]
+        )
+
 
 def _fill_with_holdings_commands(ws, company_id, date_str, data_items_dict):
     column_generator = excel_cols()
@@ -134,25 +166,24 @@ def _fill_with_holdings_commands(ws, company_id, date_str, data_items_dict):
             data_item_label=data_items_dict[item]
         )
 
-def _get_date_var_and_label_from_freq(freq):
+def _get_date_var_dict_from_freq(freq) -> Dict[str, str]:
+    date_dict = {
+        'IQ_PERIODDATE_BS': 'Date'
+    }
     if freq == 'Y':
-        date_var = (
-            'IQ_FISCAL_Y', 'Fiscal Year'
-        )
+        date_dict.update(dict(
+            IQ_FISCAL_Y='Fiscal Year'
+        ))
     elif freq == 'Q':
-        date_var = (
-            'IQ_ABS_PERIOD', 'Fiscal Quarter'
-        )
+        date_dict.update(dict(
+            IQ_ABS_PERIOD='Fiscal Quarter'
+        ))
     else:
         raise ValueError('Must pass Y or Q for freq')
 
-    return date_var
+    return date_dict
 
 def _date_str_to_file_format(date_str):
     return date_str.replace('/','-')
 
-def excel_cols():
-    n = 1
-    while True:
-        yield from (''.join(group) for group in itertools.product(string.ascii_uppercase, repeat=n))
-        n += 1
\ No newline at end of file
+
