@@ -17,6 +17,8 @@ def _capiq_is_done(excel):
 
 def _ciq_not_working(excel):
     a1 = _get_cell_value_by_index(excel, 1, 1)
+    if a1 is None:
+        return True  # should always have something in A1
     error_values = ('refresh', 'ciqinactive', 'error')
     return any([value in a1.lower() for value in error_values])
 
